@@ -272,7 +272,7 @@ class ClientMainWindow(QMainWindow):
             CLIENT_LOGGER.debug(f'Отправлено сообщение для {self.current_chat}: {message_text}')
             self.history_list_update()
 
-    @pyqtSlot(str)
+    @pyqtSlot(dict)
     def message(self, message):
         """
            Слот обработчик поступаемых сообщений, выполняет дешифровку
